// 检查登录
const checkLogin = () => {
  // 获取登录标识
  let userLogin = uni.getStorageSync("userLogin");
  // 如果不存在的话
  if (!userLogin || !userLogin.authcode || userLogin.expires_in <= Math.floor(new Date().getTime() / 1000)) {
    // 未登录
    return false;
  }
  // 登录成功
  return true;
};

// 登录提示
const alterLogin = () => {
  // 获取登录标识
  let userLogin = uni.getStorageSync("userLogin");
  // 如果不存在的话
  if (!userLogin || !userLogin.authcode || userLogin.expires_in <= Math.floor(new Date().getTime() / 1000)) {
    // 未登录
    uni.showModal({
      title: "请登录",
      success(res) {
        if (res.confirm) {
          // 用户点击确定按钮
          uni.navigateTo({
            url: "/pages/login/index",
          });
        }
      },
    });
    return false;
  }
  // 登录成功
  return true;
};

const onlyCheckAccess = () => {
  // 获取登录标识
  let userLogin = uni.getStorageSync("userLogin");
  // 如果不存在的话
  if (!userLogin || !userLogin.authcode || userLogin.expires_in <= Math.floor(new Date().getTime() / 1000)) {
    // 未登录
    return false;
  }
  // 登录成功
  return true;
};

// 检查企业资质
const checkShowPrice = () => {
  // 获取登录标识
  let userInfo = uni.getStorageSync("userInfo");
  // 如果未登录，不显示
  if (!userInfo) return false;
  // 未加好友不显示
  if (!userInfo.show_price) return false;
  // 登录成功
  return true;
};

// 检查城市ID
const getCity = () => {
  // 获取登录标识
  let userInfo = uni.getStorageSync("userInfo");
  // 如果不存在的话
  if (!userInfo) return "";
  // 资质ID不存在的话
  if (!userInfo.city_id) return "";
  // 登录成功
  return userInfo.city_id;
};

// 检查城市ID
const isManager = () => {
  // 获取登录标识
  let userInfo = uni.getStorageSync("userInfo");
  // 如果不存在的话
  if (!userInfo) return false;
  // 资质ID不存在的话
  if (!userInfo.is_manager) return false;
  // 登录成功
  return true;
};

// 是否要求填写城市
const alertCity = () => {
  // 获取登录标识
  let userInfo = uni.getStorageSync("userInfo");
  // 如果不存在的话
  if (!userInfo || !userInfo.city_id) {
    // 未登录
    uni.showModal({
      title: "请先选择您的城市",
      success(res) {
        if (res.confirm) {
          // 用户点击确定按钮
          uni.navigateTo({
            url: "/pages/user/info",
          });
        }
      },
    });
    return false;
  }
  // 登录成功
  return true;
};

// 检查客服推送码
const getFollowQrcode = () => {
  // 获取登录标识
  let userInfo = uni.getStorageSync("userInfo");
  // 如果不存在的话
  if (!userInfo) return "";
  // 未添加好友
  if (!userInfo.follow_qrcode) return "";
  // 返回结果
  return userInfo.follow_qrcode;
};

// 检查客服推送码
const getFollowLinkUrl = () => {
  // 获取登录标识
  let userInfo = uni.getStorageSync("userInfo");
  // 如果不存在的话
  if (!userInfo) return "";
  // 未添加好友
  if (!userInfo.follow_linkurl) return "";
  // 返回结果
  return userInfo.follow_linkurl;
};

const getHasFollow = () => {
  // 获取登录标识
  let userInfo = uni.getStorageSync("userInfo");
  // 如果不存在的话
  if (!userInfo) return false;
  return userInfo.have_follow == 1;
};

export default {
  checkLogin: checkLogin,
  alterLogin: alterLogin,
  checkShowPrice: checkShowPrice,
  alertCity: alertCity,
  getFollowQrcode: getFollowQrcode,
  getFollowLinkUrl: getFollowLinkUrl,
  getCity: getCity,
  isManager: isManager,
  getHasFollow: getHasFollow,
};
